@@ -1,10 +1,5 @@
 package Data::Transmute;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-13'; # DATE
-our $DIST = 'Data-Transmute'; # DIST
-our $VERSION = '0.039'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
@@ -14,6 +9,12 @@ use Ref::Util qw(is_hashref is_arrayref is_plain_hashref is_plain_arrayref);
 use Scalar::Util qw(refaddr);
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Data-Transmute'; # DIST
+our $VERSION = '0.040'; # VERSION
+
 our @EXPORT_OK = qw(transmute_data reverse_rules);
 
 sub _rule_create_hash_key {
@@ -358,7 +359,7 @@ Data::Transmute - Transmute (transform) data structure using rules data
 
 =head1 VERSION
 
-This document describes version 0.039 of Data::Transmute (from Perl distribution Data-Transmute), released on 2020-02-13.
+This document describes version 0.040 of Data::Transmute (from Perl distribution Data-Transmute), released on 2024-07-17.
 
 =head1 SYNOPSIS
 
@@ -852,14 +853,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Trans
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Transmute>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Transmute>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Hash::Transform> is similar in concept. It allows transforming a hash using
@@ -881,11 +874,43 @@ L<Bencher::Scenarios::DataTransmute>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020, 2019, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Transmute>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
