@@ -3,6 +3,11 @@ package Data::Transmute::Rules::Example;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Data-Transmute'; # DIST
+our $VERSION = '0.040'; # VERSION
+
 our @RULES = (
     [create_hash_key => {name=>'a', value=>1}],
     [create_hash_key => {name=>'b', value=>2}],
@@ -24,7 +29,7 @@ Data::Transmute::Rules::Example - Example rules module
 
 =head1 VERSION
 
-This document describes version 0.039 of Data::Transmute::Rules::Example (from Perl distribution Data-Transmute), released on 2020-02-13.
+This document describes version 0.040 of Data::Transmute::Rules::Example (from Perl distribution Data-Transmute), released on 2024-07-17.
 
 =head1 HOMEPAGE
 
@@ -34,6 +39,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Trans
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Transmute>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2020, 2019, 2015 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Transmute>
@@ -42,15 +76,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
